@@ -11,6 +11,7 @@
 
 namespace Symfony\Polyfill\Tests\Php72;
 
+use PHPUnit\Framework\TestCase;
 use Symfony\Polyfill\Php72\Php72 as p;
 
 /**
@@ -18,7 +19,7 @@ use Symfony\Polyfill\Php72\Php72 as p;
  *
  * @covers Symfony\Polyfill\Php72\Php72::<!public>
  */
-class Php72Test extends \PHPUnit_Framework_TestCase
+class Php72Test extends TestCase
 {
     /**
      * @covers Symfony\Polyfill\Php72\Php72::utf8_encode
@@ -64,4 +65,26 @@ class Php72Test extends \PHPUnit_Framework_TestCase
 
         $this->assertNull(@spl_object_id(123));
     }
+
+    /**
+     * @covers Symfony\Polyfill\Php72\Php72::sapi_windows_vt100_support
+     */
+    public function testSapiWindowsVt100Support()
+    {
+        if ('\\' !== DIRECTORY_SEPARATOR) {
+            $this->markTestSkipped('Windows only test');
+        }
+
+        $this->assertFalse(sapi_windows_vt100_support(STDIN, true));
+    }
+
+    /**
+     * @covers Symfony\Polyfill\Php72\Php72::stream_isatty
+     */
+    public function testStreamIsatty()
+    {
+        $fp = fopen('php://temp', 'r+');
+        $this->assertFalse(stream_isatty($fp));
+        fclose($fp);
+    }
 }
